# What's Changed

> Gewechat 已经停止维护，此版本提供了 `微信客服` 的接入方式，可以在直接微信内聊天。这是微信官方推出的接入方式，因此没有风控风险。详见 [AstrBot 接入企业微信](https://astrbot.app/deploy/platform/wecom.html)。此接入方式处于测试阶段，有问题请及时在 GitHub 上提交 Issue。

1. 支持接入微信客服。